/*
 * Copyright 2002-2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.web.servlet.mvc.method.condition;

import java.util.Collection;
import javax.servlet.http.HttpServletRequest;

/**
 * {@link RequestCondition} implementation that represents a logical OR (i.e. ||).
 *
 * @author Arjen Poutsma
 * @since 3.1
 */
class LogicalDisjunctionRequestCondition<T extends RequestCondition> extends RequestConditionComposite<T> {

	LogicalDisjunctionRequestCondition(Collection<T> conditions) {
		super(conditions);
	}

	public boolean match(HttpServletRequest request) {
		if (isEmpty()) {
			return true;
		}
		for (RequestCondition condition : getConditions()) {
			if (condition.match(request)) {
				return true;
			}
		}
		return false;
	}

	@Override
	protected String getToStringInfix() {
		return " || ";
	}

}
